# History

## 0.2.0

* Add grid positions annotation
* Add OSMesa rendering context for off-screen rendering
* Add geometry shader support
* Add tests and a handful of new examples
* Fix rendering meshes
* Regularize uniform names across shaders

## 0.1.0

* First release on PyPI.
